/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include "grbl.h"


void initBusServo()
{
    
    UART_BusServo_Start();
    
    // set the start positions
    SetServoAngleA(1.57);
    SetServoAngleB(3.14);
    SetPenServoUp(true);
    
    CyDelay(400); //give servos time to get there
    
    
  
  //set the machine position offset from 0,0 because this machine can't go to 0,0
  sys_position[X_AXIS] = X_PEN_INIT * settings.steps_per_mm[X_AXIS];
  sys_position[Y_AXIS] = Y_PEN_INIT * settings.steps_per_mm[Y_AXIS];

  // start the interupt routine that syncs the motion
  isr_Pen_Move_StartEx(pen_Move_isr);
    
}

// this interrupt routine runs at a few hertz.  It syncs the servos with the machine position
void pen_Move_isr()
{  
  exec_pen_move = true;
}

void BusServoUpdate()
{
  int32_t current_position[N_AXIS]; // Copy current state of the system position variable
  float print_position[N_AXIS];  
  
  memcpy(current_position,sys_position,sizeof(sys_position)); // do we need this memcpy?
  
  system_convert_array_steps_to_mpos(print_position,current_position); // get the position in MCS   
  
  law_of_cosines(print_position[X_AXIS], print_position[Y_AXIS], print_position[Z_AXIS]);
}

// Px and Py are the desired pen location.
int law_of_cosines(float Px, float Py, float z)
{
	float d; // distance of pen from hub
	float T1, T2, T3; // intermediate angles in calculations
	float A1, A2; // the servo arm angles 
	
    //do penup/down first
    SetPenServoUp(z>=0);
  
	// see blog post for more details on the calculations
	
	// check to make sure it does not bump into the base
	if(Px < PEN_MIN_X)
		return 0;
	
	// Step 1
	d = sqrt(Px * Px + Py * Py);
	T1 = atan2(Py, Px);
  
 
	
	// check the distance
	if (d >= L1 + L2)
		return 0; // point is to far to reach	
	
	//Step 2
	T2 = acos( (L1*L1 + d * d - L2*L2) / (2 * L1 * d) );
	
	//Step 3
	T3 = acos( (L1 * L1 + L2 * L2 - d * d) / (2 * L1 * L2) );
	
	//Step 4
	A1 = T1 + T2;
	A2 = A1 + T3;
	
	// check to make sure angles do not exceed limits of joints
	if (A1 < SERVO_A_MIN_RAD || A1 > SERVO_A_MAX_RAD)
    return 0;
  
  if (A2 < SERVO_B_MIN_RAD || A2 > SERVO_B_MAX_RAD)
    return 0;
  
	// if links are not crossed or bumping with each other.
	if ( (A2 - A1) < SERVO_ARM_CLEAR_ANG)
    return 0;
  
  
 
  
	// set the servos
  SetServoAngleA(A1);
  SetServoAngleB(A2);
  
  
	return 1;
}

void SetServoAngleA(float angle) // upper servo
{
    angle = angle * 180 / PI;
    angle = map((long)angle, SERVO_A_MIN_ANGLE, SERVO_A_MAX_ANGLE, SERVO_MAX_VAL, SERVO_MIN_VAL);
    LobotSerialServoMove(SERVO_A_ID, angle, PEN_SERVO_SPEED);
}


void SetServoAngleB(float angle) // lower servo
{
    angle = angle * 180 / PI;
    angle = map((long)angle, SERVO_B_MIN_ANGLE, SERVO_B_MAX_ANGLE, SERVO_MIN_VAL, SERVO_MAX_VAL);
    LobotSerialServoMove(SERVO_B_ID, angle, PEN_SERVO_SPEED);
}

void SetPenServoUp(int up)
{
    if (up)        
        LobotSerialServoMove(PEN_SERVO_ID, PEN_UP_ANGLE, PEN_SERVO_SPEED);
    else
        LobotSerialServoMove(PEN_SERVO_ID, PEN_DOWN_ANGLE, PEN_SERVO_SPEED);
}

uint8_t LobotCheckSum(uint8_t buf[])
{
  uint8_t i;
  uint16_t temp = 0;
  for (i = 2; i < buf[3] + 2; i++) {
    temp += buf[i];
  }
  temp = ~temp;
  i = (uint8_t)temp;
  return i;
}

void LobotSerialServoMove(uint8_t id, int16_t position, uint16_t time)
{
  
  if(position < 0)
    position = 0;
  if(position > 1000)
    position = 1000;
  BusServoBufffer[0] = BusServoBufffer[1] = LOBOT_SERVO_FRAME_HEADER;
  BusServoBufffer[2] = id;
  BusServoBufffer[3] = 7;
  BusServoBufffer[4] = LOBOT_SERVO_MOVE_TIME_WRITE;
  BusServoBufffer[5] = GET_LOW_BYTE(position);
  BusServoBufffer[6] = GET_HIGH_BYTE(position);
  BusServoBufffer[7] = GET_LOW_BYTE(time);
  BusServoBufffer[8] = GET_HIGH_BYTE(time);
  BusServoBufffer[9] = LobotCheckSum(BusServoBufffer);
  
  UART_BusServo_PutArray(BusServoBufffer, BusServoBufffer[3] + 3);
}

// converts one range to another.... like 0 to 1000 servo move units to -30 to 210 degress of ServoA and Servo B
// 90 would yield 500 move units
long map(long x, long in_min, long in_max, long out_min, long out_max)
{
  return (x - in_min) * (out_max - out_min) / (in_max - in_min) + out_min;
}

/* [] END OF FILE */
