/* ========================================
 *
 * Barton Dring
 * Line-us clone servo kinematics and control
 * Open Source CCSA 3.0 
 *  2/2017
 *
 * ========================================
*/
#include "grbl.h"

point penTip, penA, penB, joint1;  // these are points in 2D space
float angLongCrank, angShortCrank; // these are angles of the cranks

// initialize the hardware and move to the startup locations
void initLineUs()
{
  exec_pen_move = false;
  
  // start the PWMs
  PWM_Servo_A_Start();
  PWM_Servo_B_Start();
  PWM_Servo_Z_Start();  
  
  // set the initial PWM values
  
  setAngleA_rad(1.57);
  
 
  setAngleB_rad(3.14);
  setPenUp(true);
  
  CyDelay(400); //give servos time to get there 
  
  //set the machine position offset from 0,0 because this machine can't go to 0,0
  sys_position[X_AXIS] = X_PEN_INIT * settings.steps_per_mm[X_AXIS];
  sys_position[Y_AXIS] = Y_PEN_INIT * settings.steps_per_mm[Y_AXIS];
  
  // start the interupt routine that syncs the motion
  isr_Pen_Move_StartEx(pen_Move_isr);
  
}

// this interrupt routine runs at a few hertz.  It syncs the servos with the machine position
void pen_Move_isr()
{  
  exec_pen_move = true;
}

// Px and Py are the desired pen location.
int law_of_cosines(float Px, float Py, float z)
{
	float d; // distance of pen from hub
	float T1, T2, T3; // intermediate angles in calculations
	float A1, A2; // the servo arm angles 
	
  //do penup/down first
  setPenUp(z>=0);
  
	// see blog post for more details on the calculations
	
	// check to make sure it does not bump into the base
	if(Px < PEN_MIN_X)
		return 0;
	
	// Step 1
	d = sqrt(Px * Px + Py * Py);
	T1 = atan2(Py, Px);
  
 
	
	// check the distance
	if (d >= L1 + L2)
		return 0; // point is to far to reach	
	
	//Step 2
	T2 = acos( (L1*L1 + d * d - L2*L2) / (2 * L1 * d) );
	
	//Step 3
	T3 = acos( (L1 * L1 + L2 * L2 - d * d) / (2 * L1 * L2) );
	
	//Step 4
	A1 = T1 + T2;
	A2 = A1 + T3;
	
	// check to make sure angles do not exceed limits of joints
	if (A1 < SERVO_A_MIN_RAD || A1 > SERVO_A_MAX_RAD)
    return 0;
  
  if (A2 < SERVO_B_MIN_RAD || A2 > SERVO_B_MAX_RAD)
    return 0;
  
	// if links are not crossed or bumping with each other.
	if ( (A2 - A1) < SERVO_ARM_CLEAR_ANG)
    return 0;
  
  
 
  
	// set the servos
  setAngleA_rad(A1);
  setAngleB_rad(A2);
  
  
	return 1;
}

void setAngleA_rad(float angle)
{
  unsigned int val;
  
  angle = angle + 0.785;
  
  val = SERVOMAX_A - ((angle/3.141592654) * (SERVOMAX_A - SERVOMIN_A));
  
  PWM_Servo_A_WriteCompare(val);
  
}

// in radians
void setAngleB_rad(float angle)
{
  unsigned int val;
  
  angle = angle - SERVO_B_MIN_RAD;
  
  val = (angle/3.141592654) * (SERVOMAX_B - SERVOMIN_B) + SERVOMIN_B;
  PWM_Servo_B_WriteCompare(val);
  
}

void lineUsUpdate()
{
  int32_t current_position[N_AXIS]; // Copy current state of the system position variable
  float print_position[N_AXIS];
  
  
  
  memcpy(current_position,sys_position,sizeof(sys_position)); // do we need this memcpy?
  
  system_convert_array_steps_to_mpos(print_position,current_position); // get the position in MCS  
 
  
  law_of_cosines(print_position[X_AXIS], print_position[Y_AXIS], print_position[Z_AXIS]);
  
 
  
}





void setPenUp(int up)
{  
  if (up)
    PWM_Servo_Z_WriteCompare(SERVO_Z_UP);
  else
    PWM_Servo_Z_WriteCompare(SERVO_Z_DOWN);    
}


/* [] END OF FILE */
